.. _irf-psf:

Point spread function
=====================

The `~gammapy.irf.TablePSF` and `~gammapy.irf.EnergyDependentTablePSF` classes
represent radially-symmetric PSFs where the PSF is given at a number of offets:

.. plot:: irf/plot_fermi_psf.py

TODO: discuss noise when PSF is estimated from real or simulated data.
